@@ -46,7 +46,7 @@ def check_tiledesk_api(username, password):
         return False
 
 
-def close_converstaion(username, password, project_id, request_id):
+def close_converstation(username, password, project_id, request_id):
     """Close the converstaion."""
     headers = {
         "Content-Type": "application/json",
@@ -79,5 +79,5 @@ if __name__ == "__main__":
 
     client_id = get_ga_client_id(USERNAME, PASSWORD, _project_id, _requests_id)
     print(client_id)
-    closed = close_converstaion(USERNAME, PASSWORD, _project_id, _requests_id)
+    closed = close_converstation(USERNAME, PASSWORD, _project_id, _requests_id)
     print(closed)
